@@ -1,4 +1,4 @@
-# @(#)Ident: Bob.pm 2013-04-03 17:46 pjf ;
+# @(#)Ident: Bob.pm 2013-05-05 22:54 pjf ;
 
 package Bob;
 
@@ -10,7 +10,7 @@ sub whimper { print {*STDOUT} $_[ 0 ]."\n"; exit 0 }
 
 BEGIN { my $reason; $reason = CPANTesting::should_abort and whimper $reason; }
 
-use version; our $VERSION = qv( '1.11' );
+use version; our $VERSION = qv( '1.14' );
 
 use File::Spec::Functions qw(catfile);
 use Module::Build;
@@ -68,20 +68,22 @@ sub __get_build_class { # Which subclass of M::B should we create?
 sub __get_cleanup_list {
    my $p = shift; my $distname = shift;
 
-   return [ q(Debian_CPANTS.txt), "${distname}-*",
+   return [ q(Debian_CPANTS.txt), q(MANIFEST.bak), "${distname}-*",
             map { ( q(*/) x $_ ).q(*~) } 0..5 ];
 }
 
 sub __get_git_repository {
-   return (split q( ), (map  { s{ : }{/}mx; s{ @ }{://}mx; $_ }
-                        grep { m{ \A origin }mx }
-                           qx{ git remote -v 2>/dev/null })[ 0 ] || q())[ 1 ];
+   return (map  { s{ : }{/}mx; s{ @ }{://}mx; $_ }
+           grep { m{ \A git }mx }
+           map  { s{ \s+ }{ }gmx; (split ' ', $_)[ 1 ] }
+           grep { m{ \A origin }mx }
+           qx{ git remote -v 2>/dev/null })[ 0 ];
 }
 
 sub __get_no_index {
    my $p = shift;
 
-   return { directory => $p->{no_index_dir} || [ qw(examples inc t) ] };
+   return { directory => $p->{no_index_dir} || [ qw(examples inc share t) ] };
 }
 
 sub __get_notes {
